# PHP Developer Utilities

A collection of PHP 7 classes useful for code under construction.

Branch      | Status
----------- | ------
[master][5] | [![Build Status][8]][7]
[dev][6]    | [![Build Status][9]][7]

## Getting Started

This library is registered on [packagist][3], so you can easily include it in
your project using [composer][4].

    composer require jpuck/phpdev

Don't forget to require the autoloader in your script.

```php
<?php
require_once 'vendor/autoload.php';
```

## Functions

### `mixed print_rt ( mixed $expression [, bool $return = false ] )`

Tabulator wrapper for [`print_r`][1] replaces 8 spaces with a tab.

```php
use jpuck\phpdev\Functions as jp;

$array = [
	'first' =>
	[
		'second' =>
		[
			'third' =>
			[
				'forth' =>
				[
					'fifth' => 5
				]
			]
		]
	]
];

print_r($array);

jp::print_rt($array);
```

Example displayed on console with tabs set to 4 spaces:

>     Array
>     (
>         [first] => Array
>             (
>                 [second] => Array
>                     (
>                         [third] => Array
>                             (
>                                 [forth] => Array
>                                     (
>                                         [fifth] => 5
>                                     )
>
>                             )
>
>                     )
>
>             )
>
>     )
>     Array
>     (
>         [first] => Array
>         (
>             [second] => Array
>             (
>                 [third] => Array
>                 (
>                     [forth] => Array
>                     (
>                         [fifth] => 5
>                     )
>
>                 )
>
>             )
>
>         )
>
>     )


### `mixed arr_export ( array $array [, bool $return = false ] )`

Format arrays using [`var_export`][2] with tabs, square brackets, and
no trailing spaces after arrows to newlines.

```php
use jpuck\phpdev\Functions as jp;

$array = [
	'first' =>
	[
		'second' =>
		[
			'third' =>
			[
				'forth' =>
				[
					'fifth' => 5
				]
			]
		]
	]
];

var_export($array);

jp::arr_export($array);
```
Example displayed on console with tabs set to 4 spaces:

>     array (
>       'first' => 
>       array (
>         'second' => 
>         array (
>           'third' => 
>           array (
>             'forth' => 
>             array (
>               'fifth' => 5,
>             ),
>           ),
>         ),
>       ),
>     )
>
>     [
>         'first' =>
>         [
>             'second' =>
>             [
>                 'third' =>
>                 [
>                     'forth' =>
>                     [
>                         'fifth' => 5,
>                     ],
>                 ],
>             ],
>         ],
>     ]

**NOTICE:** [The documentation][2] on using this function with objects is clear.

> Note:
> To be able to evaluate the PHP generated by `var_export()`, all processed
> objects must implement the magic `__set_state` method. Note that StdClass does
> not implement `__set_state()`.

```php
$function = function(){};

$a = [
	'object' => new stdClass,
	'function' => $function,
];

$b = var_export($a, true);

eval("print_r($b);");
```

The above code will result in the following errors:

> PHP Fatal error:  Uncaught Error:
Call to undefined method stdClass::__set_state()
>
> PHP Fatal error:  Uncaught Error:
Call to undefined method Closure::__set_state()

## Exceptions

### `Unimplemented` Method

```php
use jpuck\phpdev\Exceptions\Unimplemented;

class MyClass {
	public function foo() {
		// completed code
		return true;
	}

	/**
	 * @throws Unimplemented
	 */
	public function bar() {
		// work in progress

		throw new Unimplemented(__METHOD__);

		return true;
	}
}
```

  [1]:http://php.net/manual/en/function.print-r.php
  [2]:http://php.net/manual/en/function.var-export.php
  [3]:https://packagist.org/packages/jpuck/phpdev
  [4]:https://getcomposer.org/
  [5]:https://github.com/jpuck/phpdev/tree/master
  [6]:https://github.com/jpuck/phpdev/tree/develop
  [7]:https://travis-ci.org/jpuck/phpdev
  [8]:https://travis-ci.org/jpuck/phpdev.svg?branch=master
  [9]:https://travis-ci.org/jpuck/phpdev.svg?branch=dev
